@@ -1,4 +1,8 @@
 package SRU::Response::Explain;
+{
+  $SRU::Response::Explain::VERSION = '1.01';
+}
+#ABSTRACT: A class for representing SRU explain responses
 
 use strict;
 use warnings;
@@ -8,25 +12,6 @@ use SRU::Utils qw( error );
 use SRU::Utils::XML qw( element );
 use Carp qw( croak );
 
-=head1 NAME
-
-SRU::Response::Explain - A class for representing SRU explain responses
-
-=head1 SYNOPSIS
-    
-    use SRU::Response;
-    my $response = SRU::Response::Explain->new( $request );
-
-=head1 DESCRIPTION
-
-=head1 METHODS
-
-=head2 new()
-
-The constructor which requires that you pass in a SRU::Request::Explain
-object.
-
-=cut
 
 sub new {
     my ($class,$request) = @_;
@@ -45,24 +30,6 @@ sub new {
     return $self;
 }
 
-=head2 version()
-
-=head2 record()
-
-=head2 addDiagnostic()
-
-Add a SRU::Response::Diagnostic object to the response.
-
-=head2 diagnostics()
-
-Returns an array ref of SRU::Response::Diagnostic objects relevant 
-for the response.
-
-=head2 extraResponseData()
-
-=head2 echoedExplainRequest()
-
-=cut
 
 SRU::Response::Explain->mk_accessors( qw(
     version 
@@ -82,9 +49,6 @@ sub record {
     return $self->{record};
 }
 
-=head2 asXML()
-
-=cut
 
 sub asXML {
     my $self = shift;
@@ -107,3 +71,58 @@ EXPLAIN_XML
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+SRU::Response::Explain - A class for representing SRU explain responses
+
+=head1 SYNOPSIS
+    
+    use SRU::Response;
+    my $response = SRU::Response::Explain->new( $request );
+
+=head1 DESCRIPTION
+
+=head1 METHODS
+
+=head2 new()
+
+The constructor which requires that you pass in a SRU::Request::Explain
+object.
+
+=cut
+
+=head2 version()
+
+=head2 record()
+
+=head2 addDiagnostic()
+
+Add a SRU::Response::Diagnostic object to the response.
+
+=head2 diagnostics()
+
+Returns an array ref of SRU::Response::Diagnostic objects relevant 
+for the response.
+
+=head2 extraResponseData()
+
+=head2 echoedExplainRequest()
+
+=cut
+
+=head2 asXML()
+
+=cut
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Ed Summers.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
